AaveSub

Enum AaveSub 

pub enum AaveSub {
    Activate,
    Deactivate {
        market_name: String,
    },
    Update {
        chunk_size: u64,
        to_block: String,
        verify: VerifyFlags,
        verify_all_interval: u64,
        stop_after_one_chunk: bool,
        dry_run: bool,
        backup: bool,
        no_backup: bool,
    },
    Position {
        command: AavePositionSub,
    },
}
The aave command group.

Variants



Activate

Activate an Aave market. Positions for activated markets are included when running degenbot aave position update.



Deactivate

Deactivate an Aave market. Positions for deactivated markets are not included when running degenbot aave position update.

Fields

market_name: String

Market name to flip (default: Aave Ethereum Market).



Update

Update positions for active Aave markets.

Fields

chunk_size: u64

The maximum number of blocks to process before committing changes to the database.

to_block: String

The last block in the update range. Must be a valid block identifier: ‘earliest’, ‘finalized’, ‘safe’, ‘latest’, ‘pending’. An identifier can be given with an optional offset, e.g. ‘latest:-64’ stops 64 blocks before the chain tip, ‘safe:128’ stops 128 blocks after the last ‘safe’ block.

verify: VerifyFlags

The pre-commit verification gates.

verify_all_interval: u64

Block interval for the --verify-all full-verification gate. A chunk that crosses or lands-on a multiple of this interval triggers a pre-commit market-wide verify. Ignored unless --verify-all is set.

stop_after_one_chunk: bool

Stop processing after the first chunk.

dry_run: bool

Preview changes without committing to the database.

backup: bool

Create a database backup after the completion verification runs (once per market, at the end of the run).

no_backup: bool

Disable the completion backup.



Position

Position commands.

Fields

command: AavePositionSub

The position command.