pub enum ExchangeSub {
Activate {
chain: String,
name: String,
},
Deactivate {
chain: String,
name: String,
},
List {
chain: Option<String>,
},
}Expand description
The exchange command group.
Variants
Activate
Activate the exchange. Liquidity pools for all activated exchanges are included when running “pool update”.
Fields
Deactivate
Deactivate the exchange. Liquidity pools for all deactivated exchanges are not included when running “pool update”.
Fields
List
List the supported exchanges and their activation state.